from enum import Enum


class Alloy(Enum):
    TI6AL4V = "Ti6Al4V"
    IN718 = "IN718"
    SS316L = "SS316L"
    ALSI10MG = "AlSi10Mg"
    IN625 = "IN625"
    MARAGING_STEEL_M300 = "Maraging steel M300"
    TI6AL4V_ELI = "Ti6Al4V ELI"
    SS17_4PH = "SS17-4PH"
    COCRMO = "CoCrMo"
    H13_TOOL_STEEL = "H13 Tool Steel"
    ALSI7MG06 = "AlSi7Mg0.6"
    SS15_5PH = "SS15-5PH"
    CUCRZR = "CuCrZr"
    AL12SI = "Al12Si"
    COPPER = "Copper"
    HASTELLOY_X = "Hastelloy X"
    COCR = "CoCr"
    HASTELLOY_C22 = "Hastelloy C22"
    SS254 = "SS254"
    CUNI2SICR = "CuNi2SiCr"
    D2_TOOL_STEEL = "D2 Tool Steel"
    SS4340 = "SS4340"
    INVAR36 = "Invar36"
    SS304L = "SS304L"
    TI_GRADE_2 = "Ti grade 2"
    K500 = "K500"
    M2_TOOL_STEEL = "M2 Tool Steel"
    TI_GRADE_1 = "Ti grade 1"
    COCR28MO6 = "CoCr28Mo6"
    IN690 = "IN690"
    CUCP = "CuCP"
    TIALNBMO = "TiAlNbMo"
    SS304 = "SS304"
    TIAL = "TiAl"
    HY100 = "HY100"
    ALSI12 = "AlSi12"
    COCRF75 = "CoCrF75"
    AZ91D = "AZ91D"
    COCRW = "CoCrW"
    SS420C = "SS420C"
    SS4130 = "SS4130"
    CUCRZRTI = "CuCrZrTi"
    STEEL_8620L = "8620L Steel"
    AL2319 = "Al2319"
    IRON_0004C = "Iron (0.004%C)"
    SS316 = "SS316"
    IRON_002C = "Iron (0.02%C)"
    MAR_M_247 = "Mar M 247"
    W22FE33NI = "W22Fe33Ni"
    STEEL_4140 = "4140 Steel"
    S50C = "S50C"
    S75C = "S75C"
    A2_TOOL_STEEL = "A2 Tool Steel"
    S105C = "S105C"
    SS_CX = "SS CX"
    ALLOY_7050 = "7050 alloy"
    S33C = "S33C"
    IN600 = "IN600"
    NB = "Nb"
